Crate holochain_common

Crate holochain_common 

Modules

env_vars
Holochain uses a number of environment variables that can be set, for easy configuration for aspects of the system. Below is the complete list of them, and what they are used for.
paths

Macros

new_relic_setup

Constants

DEFAULT_PASSPHRASE